/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFpX̕`

	Copyright 2015-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void drawShape(PtlPage& page);

int main(int argc, char* argv[])
{
	if (argc < 3) {
		printf("usage: DrawShape.exe in-pdf-file out-pdf-file\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		// y[WRei̎擾
		PtlPages& pages = doc.getPages();

		if (pages.isEmpty()){
			printf("y[WRei\n");
			return 1;
		}

		// 擪y[W̎擾
		PtlPage page = pages.get(0);

		// pX̕`
		drawShape(page);

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}
	return 0;
}

void drawShape(PtlPage& page)
{
	// y[WReg̎擾
	PtlContent& content = page.getContent();

	// y[WTCY
	PtlSize pageSize = page.getSize();

	// `̕`
	PtlRect rect(10.0f, 10.0f, pageSize.getWidth()-10.0f, pageSize.getHeight()-10.0f);
	PtlColorDeviceRGB colorFill(1.0f, 0.0f, 0.0f);
	PtlColorDeviceRGB colorStroke(0.0f, 0.0f, 1.0f);
	PtlParamDrawShape::LINE_STYLE lineStyle = PtlParamDrawShape::LINE_STYLE_SOLID;
	//PtlParamDrawShape::LINE_STYLE lineStyle = PtlParamDrawShape::LINE_STYLE_DASHED;
	//PtlParamDrawShape::LINE_WIDTH lineWidth = PtlParamDrawShape::LINE_WIDTH_THIN;
	//PtlParamDrawShape::LINE_WIDTH lineWidth = PtlParamDrawShape::LINE_WIDTH_MIDDLE;
	PtlParamDrawShape::LINE_WIDTH lineWidth = PtlParamDrawShape::LINE_WIDTH_THICK;

	// ۊp`̕`
	PtlParamDrawShape paramDrawShape;
	paramDrawShape.setLineStyle(lineStyle);
	paramDrawShape.setLineWidth(lineWidth);
	paramDrawShape.setLineColor(colorStroke);
	paramDrawShape.setFillColor(colorFill);
	paramDrawShape.setOpacity(0.5f);
	content.drawRoundRect(rect, 10.0f, 10.0f, paramDrawShape);

	// `̕`
	PtlRect rect2(30.0f, 30.0f, pageSize.getWidth()-30.0f, pageSize.getHeight()-30.0f);
	PtlColorDeviceRGB colorFill2(1.0f, 1.0f, 0.0f);
	PtlColorDeviceRGB colorStroke2(0.0f, 1.0f, 1.0f);

	paramDrawShape.setLineColor(colorStroke2);
	paramDrawShape.setFillColor(colorFill2);
	paramDrawShape.setOpacity(0.3f);
	content.drawRect(rect2, paramDrawShape);

	// ~̕`
	content.drawCircle(rect2, paramDrawShape);

	// ̕`
	PtlColorDeviceRGB colorStroke3(0.0f, 1.0f, 0.0f);
	paramDrawShape.setLineColor(colorStroke3);
	content.drawLine(PtlPoint(30.0f,30.0f), PtlPoint(pageSize.getWidth()-30,pageSize.getHeight()-30.0f), paramDrawShape);
	content.drawLine(PtlPoint(30.0f,pageSize.getHeight()-30.0f), PtlPoint(pageSize.getWidth()-30.0f,30.0f), paramDrawShape);
}
