/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFؖZLeB̐ݒ

	Copyright 2013-2021 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

void encryptPubKeyPKCS12(PtlEncryptPubKey& enc, PtlParamInput& inputPfx, const char* password);
void encryptPubKeyX509(PtlEncryptPubKey& enc, PtlParamInput& inputCer);
void setPubKey(PtlRecipient& recipient);

int main(int argc, char* argv[])
{
	if (argc < 6) {
		printf("usage: Encrypt.exe in-pdf-file out-pdf-file Í ؖ ؖfile [ؖpX[h(pfx)]\n");
		printf("Í\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
		printf("ؖ\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);
		PtlParamInput inputPfx;

		switch (argv[3][0]) {
		case '0':
		case '1':
		case '2':
			break;
		default:
			printf("usage: Encrypt.exe in-pdf-file out-pdf-file Í ؖ(pfx,cer) [ؖpX[h(pfx)]\n");
			printf("Í\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
			printf("ؖ\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
			return 1;
		}

		switch (argv[4][0]) {
		case '1':
			break;
		case '0':
			if (argc > 6) {
				break;
			}
		default:
			printf("usage: Encrypt.exe in-pdf-file out-pdf-file Í ؖ(pfx,cer) [ؖpX[h(pfx)]\n");
			printf("Í\n0 : 128 bit RC4  1 : 128 bit AES  2 : 256 bit AES \n");
			printf("ؖ\n0 : PKCS12(.pfx)  1 : X509(.cer) \n");
			return 1;
		}

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		if (argc > 5) {
			inputPfx = PtlParamInput(argv[5]);
			// JZLeBnh
			switch (argv[3][0])
			{
			case '0':
				{
					// 128 bit RC4
					PtlEncryptPubKey128RC4 enc;
					switch (argv[4][0]) {
					case '0':
						encryptPubKeyPKCS12(enc, inputPfx, argv[6]);
						break;
					case '1':
						encryptPubKeyX509(enc, inputPfx);
						break;
					}
					doc.setEncrypt(enc);
				}
				break;
			case '1':
				{
					// 128 bit AES
					PtlEncryptPubKey128AES enc;
					switch (argv[4][0]) {
					case '0':
						encryptPubKeyPKCS12(enc, inputPfx, argv[6]);
						break;
					case '1':
						encryptPubKeyX509(enc, inputPfx);
						break;
					}
					doc.setEncrypt(enc);
				}
				break;
			case '2':
				{
					// 256 bit AES
					PtlEncryptPubKey256AES enc;
					switch (argv[4][0]) {
					case '0':
						encryptPubKeyPKCS12(enc, inputPfx, argv[6]);
						break;
					case '1':
						encryptPubKeyX509(enc, inputPfx);
						break;
					}
					doc.setEncrypt(enc);
				}
				break;
			default:
				break;
			}
		}

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

void encryptPubKeyPKCS12(PtlEncryptPubKey& enc, PtlParamInput& inputPfx, const char* password)
{
	// ̑SẴRecÍ
	enc.setEncryptComponent(PtlEncrypt::ENCRYPT_ALL);

	PtlRecipients& recipients = enc.getRecipients();

	PtlRecipient recipient;
	recipient.setPKCS12(inputPfx, password);
	// ݒ
	setPubKey(recipient);
	
	recipients.append(recipient);
}

void encryptPubKeyX509(PtlEncryptPubKey& enc, PtlParamInput& inputCer)
{
	// ̑SẴRecÍ
	enc.setEncryptComponent(PtlEncrypt::ENCRYPT_ALL);

	PtlRecipients& recipients = enc.getRecipients();

	PtlRecipient recipient;
	recipient.setX509(inputCer);
	// ݒ
	setPubKey(recipient);
	
	recipients.append(recipient);
}

void setPubKey(PtlRecipient& recipient)
{
	PtlEncryptPermissionPubKey typ;

	// ̐ݒ
	// PERM_PRINT_LOW = 1, /* 𑜓x */
	typ.setPrint(PtlEncryptPermissionType2::PERM_PRINT_LOW);

	// ύX̐ݒ
	// PERM_MODIFY_ASSEMBLEDOC = 1, /* y[W̑}A폜A] */
	typ.setModify(PtlEncryptPermissionType2::PERM_MODIFY_ASSEMBLEDOC);

	// eLXgA摜Ȃ̓ẽRs[Lɂ邩ǂ̐ݒ
	// false: LɂȂ
	typ.setCopy(false);

	// XN[[_[foCX̃eLXgANZXLɂ邩ǂ̐ݒ
	// true: Lɂ
	typ.setAccessibility(true);

	// [UANZXtO̐ݒ
	recipient.setPermission(typ);
}
