/*
	Antenna House PDF Tool API V7.0
	C++ Interface sample program

	TvFeLXgănCCg

	Copyright 2018 Antenna House, Inc.
*/

#include <PdfTk.h>
#include <stdio.h>

using namespace PdfTk;

int main(int argc, char* argv[])
{
	if (argc < 4) {
		printf("usage: SearchTextAndHighlight.exe in-pdf-file out-pdf-file keyword\n");
		return 1;
	}
	try
	{
		PtlParamInput input(argv[1]);
		PtlParamOutput output(argv[2]);
		PtlParamString keyword(argv[3]);

		PtlPDFDocument doc;

		// PDFt@C[h܂B
		doc.load(input);

		PtlPages& pages = doc.getPages();

		// nCCg߂̐F
		PtlColorDeviceRGB colorRed(1.0f, 0.0f, 0.0f);

		// ׂ̈̃p[^
		PtlParamSearchText paramSearchText;

		paramSearchText.appendText(keyword);
		paramSearchText.setTextType(PtlParamSearchText::TEXT_RAW);

		// sČʃRei擾
		PtlSearchTextResults results = doc.searchText(paramSearchText);
		int numResults = results.getCount();
		for (int i=0; i<numResults; ++i) {
			// ʎ擾
			PtlSearchTextResult& result = results.get(i);
			// ɎgpL[[h
			PtlParamString keyword = result.getKeyword();
			//const char* keywordC = keyword.c_str();

			// qbgy[Wԍ
			int pageNumber = result.getPageNumber();
			PtlPage page = pages.get(pageNumber);
			PtlAnnots& annots = page.getAnnots();

			// ʏڍ׃Rei擾
			PtlSearchTextResultDetails& details = result.getResultDetails();
			int numDetails = details.getCount();
			for (int j=0; j<numDetails; ++j) {
				// ʏڍ׎擾
				PtlSearchTextResultDetail& resultDetail = details.get(j);
				// ɎgpL[[h̕
				PtlParamString keyword = resultDetail.getKeyword();
				//const char* keywordC = keyword.c_str();
				// ɎgpL[[h͂̕QuadPoint
				PtlQuadPoint quad = resultDetail.getQuadPoint();
				// ɎgpL[[h̕񂪏c
				bool verticalWriting = resultDetail.isVerticalWriting();

				// ɃnCCg߂t
				PtlAnnotHighlight annot;
				PtlQuadPoints& quads = annot.getQuadPoints();
				quads.append(quad);
				annot.setVerticalDirection(verticalWriting);
				annot.setColor(colorRed);
				annot.setMarkUpCA(0.5f);

				annots.append(annot);
			}
		}

		// t@Cɕۑ܂B
		doc.save(output);

		printf("!\n");
	}
	catch (const PtlException &e)
	{
		fprintf(stderr, "Error code : %d\n %s\n", e.getErrorCode(), e.getErrorMessage().c_str());
		return 1;
	}	
	return 0;
}

