﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：開き方情報の取得

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace GetOpenMode
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 1)
            {
                Console.WriteLine("usage: GetOpenMode.exe in-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // 文書プロパティの取得
                    using (PtlDocProperty docproperty = doc.getDocProperty())
                    {
                        // 開き方の取得
                        using (PtlOpenMode openmode = docproperty.getOpenMode())
                        {
                            // ページモードの取得
                            switch (openmode.getPageMode())
                            {
                            case PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_NONE:
                                Console.WriteLine("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_NONE + " : ページのみ表示");
                                break;
                            case PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OUTLINES:
                                Console.WriteLine("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OUTLINES + " : しおりパネルとページ");
                                break;
                            case PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_THUMBS:
                                Console.WriteLine("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_THUMBS + " : サムネイルパネルとページ");
                                break;
                            case PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OC:
                                Console.WriteLine("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_OC + " : レイヤーパネルとページ");
                                break;
                            case PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_ATTACHMENTS:
                                Console.WriteLine("PageMode : " + PtlOpenMode.PAGE_MODE.PAGE_MODE_USE_ATTACHMENTS + " : 添付ファイルパネルとページ");
                                break;
                            }

                            // ページレイアウトの取得
                            switch (openmode.getPageLayout())
                            {
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_SINGLE_PAGE:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_SINGLE_PAGE + " : 単一ページ");
                                break;
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_ONE_COLUMN:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_ONE_COLUMN + " : 連続ページ");
                                break;
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_LEFT:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_LEFT + " : 奇数ページを左側にして連続見開きページ");
                                break;
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_RIGHT:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_COLUMN_RIGHT + " : 奇数ページを右側にして連続見開きページ");
                                break;
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_LEFT:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_LEFT + " : 奇数ページを左側にして見開きページ");
                                break;
                            case PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_RIGHT:
                                Console.WriteLine("PageLayout : " + PtlOpenMode.PAGE_LAYOUT.PAGE_LAYOUT_TWO_PAGE_RIGHT + " : 奇数ページを右側にして見開きページ");
                                break;
                            }

                            // オープンアクションの取得
                            using (PtlAction action = openmode.getOpenAction())
                            {
                                showAction(action);
                            }

                            // 宛先ページの取得(ページ番号は0ベース)
                            // この宛先はdoc内の宛先になります。他PDFの宛先はPtlActionGoToRのgetDestで取得します。
                            using (PtlDest dest = openmode.getOpenDest())
                            {
                                showDest(dest);
                            }

                            // ウインドウオプションを取得（論理和）
                            if (openmode.getWindowOption().HasFlag(PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_NONE))
                            {
                                Console.WriteLine("WindowOption : " + PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_NONE + " : なし");
                            }
                            if (openmode.getWindowOption().HasFlag(PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_FIT_WINDOW))
                            {
                                Console.WriteLine("WindowOption : " + PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_FIT_WINDOW + " : ページにウィンドウサイズを合わせる");
                            }
                            if (openmode.getWindowOption().HasFlag(PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_CENTER_WINDOW))
                            {
                                Console.WriteLine("WindowOption : " + PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_CENTER_WINDOW + " : ウィンドウを画面中央に配置");
                            }
                            if (openmode.getWindowOption().HasFlag(PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_FULL_SCREEN))
                            {
                                Console.WriteLine("WindowOption : " + PtlOpenMode.WINDOWS_OPTION.WINDOWS_OPTION_FULL_SCREEN + " : フルスクリーンモードで開く");
                            }

                            // ウィンドウのタイトルバーに文書タイトルを表示するかどうか取得（true: 非表示、false: 表示）
                            if (openmode.getDisplayDocTitle())
                            {
                                Console.WriteLine("DisplayDocTitle : 非表示");
                            }
                            else
                            {
                                Console.WriteLine("DisplayDocTitle : 表示");
                            }

                            // ユーザーインターフェイスオプションを取得（論理和）
                            if (openmode.getUIOption().HasFlag(PtlOpenMode.UI_OPTION.UI_OPTION_NONE))
                            {
                                Console.WriteLine("UIOption : " + PtlOpenMode.UI_OPTION.UI_OPTION_NONE + " : なし");
                            }
                            if (openmode.getUIOption().HasFlag(PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_MENUBAR))
                            {
                                Console.WriteLine("UIOption : " + PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_MENUBAR + " : メニューバーを非表示");
                            }
                            if (openmode.getUIOption().HasFlag(PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_TOOLBAR))
                            {
                                Console.WriteLine("UIOption : " + PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_TOOLBAR + " : ツールバーを非表示");
                            }
                            if (openmode.getUIOption().HasFlag(PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_WINDOWUI))
                            {
                                Console.WriteLine("UIOption : " + PtlOpenMode.UI_OPTION.UI_OPTION_HIDE_WINDOWUI + " : ウインドウコントロールを非表示");
                            }
                        }
                        // 読み上げオプション取得
                        if (docproperty.getDirection() == PtlDocProperty.DIRECTION.DIRECTION_L2R)
                        {
                            Console.WriteLine("Direction : 左から右");
                        }
                        else if (docproperty.getDirection() == PtlDocProperty.DIRECTION.DIRECTION_R2L)
                        {
                            Console.WriteLine("Direction : 右から左(中国語、日本語、韓国語のような縦書きも含む)");
                        }
                    }
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        static void showAction(PtlAction action)
        {
            switch (action.getType())
            {
            case PtlAction.ACTION_TYPE.TYPE_NONE:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_NONE + " : アクションなし");
                    break;
                }
            case PtlAction.ACTION_TYPE.TYPE_GOTO:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_GOTO + " : GoToアクション");
                    PtlActionGoTo act = (PtlActionGoTo)action;
                    // 宛先ページの取得(ページ番号は0ベース)
                    using (PtlDest dest = act.getDest())
                    {
                        showDest(dest);
                    }
                    break;
                }
            case PtlAction.ACTION_TYPE.TYPE_GOTO_R:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_GOTO_R + " : GoToRアクション");
                    PtlActionGoToR act = (PtlActionGoToR)action;
                    // ファイル間移動用PDFファイル名を取得 getFileName()
                    Console.WriteLine("FileName : " + act.getFileName());
                    // 新ウィンドウフラグを取得
                    if (act.getNewWindowFlag())
                    {
                        Console.WriteLine("NewWindowFlag : true: 新ウィンドウでオープンする");
                    }
                    else
                    {
                        Console.WriteLine("NewWindowFlag : false: しない");
                    }
                    // 宛先ページの取得(ページ番号は0ベース)
                    using (PtlDest dest = act.getDest())
                    {
                        showDest(dest);
                    }
                    break;
                }
            case PtlAction.ACTION_TYPE.TYPE_LAUNCH:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_LAUNCH + " : Launchアクション");
                    PtlActionLaunch act = (PtlActionLaunch)action;
                    // 起動ファイル名を取得
                    Console.WriteLine("FileName : " + act.getFileName());
                    // 新ウィンドウフラグを取得
                    if (act.getNewWindowFlag())
                    {
                        Console.WriteLine("NewWindowFlag : true: 新ウィンドウでオープンする");
                    }
                    else
                    {
                        Console.WriteLine("NewWindowFlag : false: しない");
                    }
                    break;
                }
            case PtlAction.ACTION_TYPE.TYPE_URI:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_URI + " : URIアクション");
                    PtlActionURI act = (PtlActionURI)action;
                    // URIを取得
                    Console.WriteLine("URI : " + act.getURI());
                    break;
                }
            case PtlAction.ACTION_TYPE.TYPE_UNKNOWN:
                {
                    Console.WriteLine("OpenAction : " + PtlAction.ACTION_TYPE.TYPE_UNKNOWN + " : 未対応アクション");
                    break;
                }
            }
        }

        static void showDest(PtlDest dest)
        {
            switch (dest.getType())
            {
            case PtlDest.DEST_TYPE.TYPE_NONE:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_NONE + " : 宛先なし");
                break;
            case PtlDest.DEST_TYPE.TYPE_XYZ:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_XYZ + " : XYZ型");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT + " : Fit型(全体表示)");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_H:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_H + " : FitH型(幅に合わせる)");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_V:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_V + " : FitV型(高さに合わせる)");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_R:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_R + " : FitR型");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_B:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_B + " : FitB型");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_BH:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_BH + " : FitBH型(描画領域の幅に合わせる)");
                break;
            case PtlDest.DEST_TYPE.TYPE_FIT_BV:
                Console.WriteLine("OpenDest : " + PtlDest.DEST_TYPE.TYPE_FIT_BV + " : FitBV型");
                break;
            }

            // 宛先ページの取得
            Console.WriteLine("宛先ページ(PageNumber) : " + dest.getPageNumber() + " ページ目");
        }
    }
}
