﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：画像ファイルのPDF化と既存PDFへのページ追加

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace InsertImagePage
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: InsertImagePage.exe in-pdf-file insert-image-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))    //元PDF
                using (PtlParamInput insertImage = new PtlParamInput(args[1]))  //挿入する画像
                using (PtlParamOutput outputFile = new PtlParamOutput(args[2])) //出力PDF
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlPages pages = doc.getPages())
                    using (PtlParamImagePage paramImagePage = new PtlParamImagePage())
                    {
                        // 画像の描画に使うパラメータクラス
                        using (PtlParamDrawImage paramDrawImage = new PtlParamDrawImage())
                        {
                            // 入力画像ストリームの設定
                            paramDrawImage.setImageStream(insertImage);

                            // マルチTiffのページ番号の設定（Tiffファイルにのみ有効） 
                            // -1を設定すると全ページを挿入します。設定しない場合は、-1が設定されたとみなします
                            paramDrawImage.setImagePageNumber(0);

                            // ページに挿入する画像パラメータの設定。
                            paramImagePage.setImage(paramDrawImage);
                        }
                        // 用紙タイプの設定 PAPER_A4 = 1, /* A4 */
                        paramImagePage.setPaperType(PtlParamImagePage.PAPER_TYPE.PAPER_A4);

                        // 画像を配置するときの余白の設定
                        paramImagePage.setMargin(20.0f, 15.0f, 20.0f, 15.0f);

                        // 画像の配置の設定 ALIGN_TOP_LEFT = 1, /* 左上 */
                        paramImagePage.setAlign(PtlParamImagePage.ALIGN.ALIGN_TOP_LEFT);

                        // 画像ページの挿入
                        //pages.insert(4, paramImagePage);// 5P目
                        pages.append(paramImagePage);// 最終
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
