﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：添付ファイルの削除

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace OutputEmbeddedFile
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: OutputEmbeddedFile.exe in-pdf-file out-pdf-file 削除方法\n");
                Console.WriteLine("削除方法\n0 : 添付ファイルの削除 1 : 添付ファイルの全削除\n");
                return;
            }
            String kind = args[2];
            switch (kind)
            {
                case "0":
                case "1":
                    break;
                default:
                    Console.WriteLine("usage: OutputEmbeddedFile.exe in-pdf-file out-pdf-file 削除方法\n");
                    Console.WriteLine("削除方法\n0 : 添付ファイルの削除 1 : 添付ファイルの全削除\n");
                    return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    //PDFファイルをロードします。
                    doc.load(inputFile);

                    //添付ファイルコンテナの取得
                    PtlEmbeddedFiles embeddedfiles = doc.getEmbeddedFiles();

                    //添付ファイルコンテナが空かどうか
                    if (embeddedfiles.isEmpty())
                    {
                        Console.WriteLine("添付ファイルコンテナが空");
                        return;
                    }

                    //添付ファイル数の取得
                    Console.WriteLine("添付ファイル数 : " + embeddedfiles.getCount());

                    switch (kind)
                    {
                    case "0":
                        // 添付ファイルの削除
                        embeddedfiles.remove(0);
                        break;
                    case "1":
                        // 添付ファイルの全削除
                        embeddedfiles.removeAll();
                        break;
                    }

                    // 別のファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
