﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：ページ削除

		※ パラメーターの指定で全ページの削除が出来ますが、全てのページを削除したらPDFとしてなりたたないのでエラーとなります。

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace RemovePages
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 3)
            {
                Console.WriteLine("usage: RemovePages.exe in-pdf-file out-pdf-file 削除方法\n");
                Console.WriteLine("削除方法\n0 : １ページ目を削除  1 : ２-３ページを削除  2 : 全ページの削除\n");
                return;
            }
            String kind = args[2];
            switch (kind)
            {
                case "0":
                case "1":
                case "2":
                    break;
                default:
                    Console.WriteLine("usage: RemovePages.exe in-pdf-file out-pdf-file 削除方法\n");
                    Console.WriteLine("削除方法\n0 : １ページ目を削除  1 : ２-３ページを削除  2 : 全ページの削除\n");
                    return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // リニアライズ
                    doc.setSaveOption(PtlPDFDocument.SAVE_OPTION.SAVE_LINEARIZE);

                    // ページ数の取得
                    Console.WriteLine("ページ数：" + doc.getPageCount());

                    using (PtlPages pages = doc.getPages())
                    {
                        // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }

                        switch (kind)
                        {
                        case "0":
                            // ページの削除
                            pages.remove(0);
                            break;
                        case "1":
                            // 複数ページの削除
                            pages.remove(1, 2);
                            break;
                        case "2":
                            // 全ページの削除
                            pages.removeAll();  // このままsaveするとエラーになります
                            break;
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
