﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：透かしの削除

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace RemoveWaterMark
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: RemoveWaterMark.exe in-pdf-file out-pdf-file watermark-name");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    string watermarkname = args[2];

                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlPages pages = doc.getPages())
                    {
                        // 透かしの削除：setNameで設定した名前を引数にする
                        doc.removeWaterMark(watermarkname);
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
