﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：文書情報の設定

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SetDocInfo
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: SetDocInfo.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // PDFの文書プロパティ
                    using (PtlDocProperty docproperty = doc.getDocProperty())
                    {
                        // PDFの文書情報
                        using (PtlDocInfo docinf = docproperty.getDocInfo())
                        {
                            // タイトルを設定
                            docinf.setTitle("タイトル");

                            // 著者を設定
                            docinf.setAuthor("作者");

                            // サブジェクトを設定
                            docinf.setSubject("サブジェクト");

                            // キーワードを設定
                            docinf.setKeywords("キーワード");

                            // クリエータを設定
                            docinf.setCreator("クリエイタ");

                            // プロデューサを設定
                            docinf.setProducer("プロデューサ");

                            // 作成日付を設定(2013/08/01 00:00:00)
                            using (PtlDate date = new PtlDate(2013, 8, 1, 0, 0, 0))
                            {
                                docinf.setCreationDate(date);
                            }

                            // 更新日付を設定(2013/8/16 23:00:00)
                            using (PtlDate date = new PtlDate(2013, 8, 16, 23, 0, 0))
                            {
                                docinf.setModDate(date);
                            }
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
