﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：マスクの設定

	Copyright 2015-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SetMask
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: SetMask.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    // ページコンテナの取得
                    using (PtlPages pages = doc.getPages())
                    {
                        // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }

                        // 1ページ目の取得
                        using (PtlPage page = pages.get(0))
                        using (PtlSize size = page.getSize())
                        {
                            using (PtlParamSetMask paramSetMask = new PtlParamSetMask())
                            using (PtlRect rect = new PtlRect(size.getWidth()/4.0f, size.getHeight()/4.0f, size.getWidth()*3.0f/4.0f, size.getHeight()*3.0f/4.0f))
                            using (PtlColorDeviceRGB color = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
                            {
                                // マスク設定
		                        paramSetMask.appendRect(rect);
		                        paramSetMask.setMaskColor(color);
		                        page.setMask(paramSetMask);
                            }
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }
    }
}
