﻿/*
	Antenna House PDF Tool API V7.0
	.NET Interface sample program

	概要：閲覧制限設定

	Copyright 2013-2021 Antenna House, Inc.
*/

using System;
using PdfTkNet;

namespace SetRestriction
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length < 2)
            {
                Console.WriteLine("usage: SetRestriction.exe in-pdf-file out-pdf-file");
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // ファイルをロードします。
                    doc.load(inputFile);

                    // 閲覧制限設定
                    setRestriction(doc);
                    
                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine(pex.getErrorCode() + " : " + pex.getErrorMessageJP());
                pex.Dispose();
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        static void setRestriction(PtlPDFDocument doc)
        {
            using (PtlParamRestriction restruction = new PtlParamRestriction())
            {
                // 閲覧可能とするURLの追加
                restruction.appendValidURL("C:\\test\\");

                // 閲覧可能とする期間の開始日(2013/1/1 15:00:30)
                using (PtlDate dateStart = new PtlDate(2013, 1, 1, 15, 0, 30))
                {
                    restruction.setValidTermStart(dateStart);
                }

                // 閲覧可能とする期間の終了日(2020/1/1 9:30:00)
                using (PtlDate dateEnd = new PtlDate(2020, 1, 1, 9, 30, 0))
                {
                    restruction.setValidTermEnd(dateEnd);
                }

                // 透かしの設定
                setWaterMark(restruction);
                
                // 閲覧制限の設定
                doc.setRestriction(restruction);
            }
        }

        static void setWaterMark(PtlParamRestriction restruction)
        {
            // 透かしの設定
            using (PtlParamWaterMarkText watermarktext = new PtlParamWaterMarkText())
            {
                // 透かしの配置の設定 ALIGN_CENTER = 5 /* 中央 */
                watermarktext.setAlign(PtlParamWaterMark.ALIGN.ALIGN_CENTER);

                // 透かしに指定する文字列の設定
                watermarktext.setString("閲覧制限テスト");

                // 透かしに指定するフォントの設定
                using (PtlParamFont font = new PtlParamFont("メイリオ", 180.0f, PtlParamFont.WEIGHT.WEIGHT_HEAVY, true, false))
                {
                    watermarktext.setFont(font);
                }

                // 透かしの文字に指定する色の設定
                using (PtlColorDeviceRGB colorText = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
                {
                    watermarktext.setTextColor(colorText);
                }

                // 透かしの文字の縁取りに指定する色の設定
                using (PtlColorDeviceRGB colorOutline = new PtlColorDeviceRGB(0.0f, 1.0f, 0.0f))
                {
                    watermarktext.setOutlineColor(colorOutline);
                }

                // 透かしのテキストを対角線上に配置する設定
                watermarktext.setWriteDiagonal(true);

                // 閲覧不可時に表示するウォーターマーク設定
                restruction.setWatermark(watermarktext);
            }
        }
    }
}
