/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：画像透かしの挿入

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class AppendImageWatermark {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java AppendImageWatermark in-pdf-file out-pdf-file watermark-image-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            // 透かしの追加
            appendWatermarkImage(doc, args[2]);
            //appendWatermarkPDF(doc, args[2]);

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void appendWatermarkImage(PtlPDFDocument doc, String pathImage) throws PtlException, Exception, Error
    {
        try (PtlParamWaterMarkImage watermarkimage = new PtlParamWaterMarkImage())  // 透かしパラメーター
        {
            try (PtlParamInput inputImage = new PtlParamInput(pathImage))      // 画像ファイル
            {
                // 画像描画パラメータに画像ファイルを設定
                watermarkimage.setImageStream(inputImage);
            }

            // 透かしの名前の設定
            watermarkimage.setName("透かしの名前");

            // 透かしを配置するときの余白の設定
            watermarkimage.setMargin(10.0f, 10.0f, 10.0f, 10.0f);

            // 透かしの配置の設定 ALIGN_TOP_LEFT = 1 /* 左上 */
            watermarkimage.setAlign(PtlParamWaterMark.ALIGN.ALIGN_TOP_LEFT);

            // 透かしのZオーダーの設定 ZORDER_FRONT = 1 /* 前面 */
            watermarkimage.setZorder(PtlParamWaterMark.ZORDER.ZORDER_FRONT);

            // 透かしを入れるページの範囲の設定 PAGE_RANGE_ODD = 3 /* 奇数ページ */
            watermarkimage.setPageRange(PtlParamWaterMark.PAGE_RANGE.PAGE_RANGE_ODD);

            // 透かしの不透明度の設定
            watermarkimage.setOpacity(0.9f);

            // 透かしをタイリングして配置するかどうかの設定
            watermarkimage.setTiling(false);

            // 透かしの倍率の設定
            watermarkimage.setScale(0.8f);

            // 透かしの設定
            doc.appendWaterMark(watermarkimage);
        }
    }

    public static void appendWatermarkPDF(PtlPDFDocument doc, String pathImage) throws PtlException, Exception, Error
    {
        try (PtlParamWaterMarkPDF watermarkpdf = new PtlParamWaterMarkPDF())  // 透かしパラメーター
        {
            try (PtlPDFDocument aDocTmp = new PtlPDFDocument();
                 PtlPages pagesCustomStamp = aDocTmp.getPages();
                 PtlParamDrawImage paramDrawImage = new PtlParamDrawImage();   // 画像描画パラメータ
                 PtlParamInput inputImage = new PtlParamInput(pathImage);      // 画像ファイル
                 PtlParamImagePage paramImagePage = new PtlParamImagePage())   // 画像ページパラメータ
            {
                // 画像描画パラメータに画像ファイルを設定
                paramDrawImage.setImageStream(inputImage);
                // 画像ページパラメータに画像描画パラメータを設定
                paramImagePage.setImage(paramDrawImage);
                // 画像ページのサイズを画像サイズにあわせる
                paramImagePage.setPaperType(PtlParamImagePage.PAPER_TYPE.PAPER_IMAGE_SIZE);
                // ページコンテナに画像ページパラメータを追加
                pagesCustomStamp.append(paramImagePage);
                // 追加された画像ページを取得する
                try (PtlPage page = pagesCustomStamp.get(0)) {
                    // 透かしに使用するPDF文書ページを設定
                    watermarkpdf.setPage(page);
                }
            }

            // 透かしの名前の設定
            watermarkpdf.setName("透かしの名前");

            // 透かしを配置するときの余白の設定
            watermarkpdf.setMargin(10.0f, 10.0f, 10.0f, 10.0f);

            // 透かしの配置の設定 ALIGN_TOP_LEFT = 1 /* 左上 */
            watermarkpdf.setAlign(PtlParamWaterMark.ALIGN.ALIGN_TOP_LEFT);

            // 透かしのZオーダーの設定 ZORDER_FRONT = 1 /* 前面 */
            watermarkpdf.setZorder(PtlParamWaterMark.ZORDER.ZORDER_FRONT);

            // 透かしを入れるページの範囲の設定 PAGE_RANGE_ODD = 3 /* 奇数ページ */
            watermarkpdf.setPageRange(PtlParamWaterMark.PAGE_RANGE.PAGE_RANGE_ODD);

            // 透かしの不透明度の設定
            watermarkpdf.setOpacity(0.9f);

            // 透かしをタイリングして配置するかどうかの設定
            watermarkpdf.setTiling(false);

            // 透かしの倍率の設定
            watermarkpdf.setScale(0.8f);

            // 透かしの設定
            doc.appendWaterMark(watermarkpdf);
        }
    }
}
