/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：テキスト抽出

    Copyright 2018-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class ExtractText {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 1)
        {
            System.out.println("usage: java ExtractText in-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空");
                    return;
                }

                // １ページ目の取得
                try (PtlPage page = pages.get(0))
                {
                    // テキスト抽出
                    extractText(page);
                }
            }
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void extractText(PtlPage page) throws PtlException, Exception, Error
    {
        try (PtlSize pageSize = page.getSize(); // ページサイズの取得
             PtlContent content = page.getContent(); // ページコンテントの取得
             PtlParamExtractText paramExtractText = new PtlParamExtractText(); // テキスト抽出パラメータ
             PtlRect rect = new PtlRect(0.0f, 0.0f, pageSize.getWidth() / 2, pageSize.getHeight() / 2)) // テキスト抽出範囲矩形
        {
             //paramExtractText.appendRect(rect);  // この行のコメントを外すと矩形領域内のテキストを抽出

             // テキスト抽出
             String text = content.extractText(paramExtractText);
             System.out.println(text);
        }
    }
}
