/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：添付ファイルの削除

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import java.io.*;
import jp.co.antenna.ptl.*;

public class RemoveEmbeddedFile {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java RemoveEmbeddedFile in-pdf-file out-pdf-file 削除方法\n");
            System.out.println("削除方法\n0 : 添付ファイルの削除 1 : 添付ファイルの全削除\n");
            return;
        }
        String kind = args[2];
        switch (kind) {
        case "0":
        case "1":
            break;
        default:
            System.out.println("usage: java RemoveEmbeddedFile in-pdf-file out-pdf-file 削除方法\n");
            System.out.println("削除方法\n0 : 添付ファイルの削除 1 : 添付ファイルの全削除\n");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            // 添付ファイルコンテナの取得
            try (PtlEmbeddedFiles embeddedfiles = doc.getEmbeddedFiles())
            {
                // 添付ファイルコンテナが空かどうか
                if (embeddedfiles.isEmpty())
                {
                    System.out.println("添付ファイルコンテナは空");
                    return;
                }

                // 添付ファイル数の取得
                System.out.println("添付ファイル数 : " + embeddedfiles.getCount());

                switch (kind)
                {
                case "0":
                    // 添付ファイルの削除
                    embeddedfiles.remove(0);
                    break;
                case "1":
                    // 添付ファイルの全削除
                    embeddedfiles.removeAll();
                    break;
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
