/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：テキスト検索して文字列をパスで囲む

    Copyright 2018-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class SearchTextAndDrawPath {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 3)
        {
            System.out.println("usage: java SearchTextAndDrawPath in-pdf-file out-pdf-file keyword");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロード
            doc.load(inputFile);

            try (PtlPages pages = doc.getPages()) // ページコンテナの取得
            {
                // ページコンテナが空かどうか
                if (pages.isEmpty())
                {
                    System.out.println("ページコンテナが空\n");
                    return;
                }

                try (PtlParamSearchText paramSearchText = new PtlParamSearchText();
                     PtlParamDrawShape paramDrawShape = new PtlParamDrawShape();
                     PtlColorDeviceRGB colorRed = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f);
                     PtlColorDeviceRGB colorBlue = new PtlColorDeviceRGB(0.0f, 0.0f, 1.0f))
                {
                    // 検索設定
                    paramSearchText.appendText(args[2]);

                    // 線の太さ
                    paramDrawShape.setLineWidth(PtlParamDrawShape.LINE_WIDTH.LINE_WIDTH_THIN);

                    // 検索実行して検索結果コンテナ取得
                    try (PtlSearchTextResults results = doc.searchText(paramSearchText))
                    {
                        int numResults = results.getCount();
                        for (int i = 0; i < numResults; ++i)
                        {
                            // 検索結果取得
                            try (PtlSearchTextResult result = results.get(i))
                            {
                                // 検索に使用したキーワード
                                String keyword = result.getKeyword();

                                // ヒットしたページ番号
                                int pageNumber = result.getPageNumber();
                                try (PtlPage page = pages.get(pageNumber);
                                     PtlContent constent = page.getContent())
                                {
                                    // 検索結果詳細コンテナ取得
                                    try (PtlSearchTextResultDetails details = result.getResultDetails())
                                    {
                                        int numDetails = details.getCount();
                                        for (int j = 0; j < numDetails; ++j)
                                        {
                                            // 検索結果詳細取得
                                            try (PtlSearchTextResultDetail resultDetail = details.get(j))
                                            {
                                                // 検索に使用したキーワードの部分文字列
                                                String keywordD = resultDetail.getKeyword();
                                                // 検索に使用したキーワードの部分文字列を囲むQuadPoint
                                                try (PtlQuadPoint quad = resultDetail.getQuadPoint();
                                                     PtlPoint tl = quad.getTopLeft();
                                                     PtlPoint tr = quad.getTopRight();
                                                     PtlPoint bl = quad.getBottomLeft();
                                                     PtlPoint br = quad.getBottomRight())
                                                {
                                                    // 文字列をパスで囲む
                                                    paramDrawShape.setLineColor(colorBlue);
                                                    constent.drawLine(bl, tl, paramDrawShape);
                                                    constent.drawLine(tl, tr, paramDrawShape);
                                                    constent.drawLine(tr, br, paramDrawShape);
                                                    // ベースライン側は赤で書く
                                                    paramDrawShape.setLineColor(colorRed);
                                                    constent.drawLine(br, bl, paramDrawShape);
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
