/*
	Antenna House PDF Tool API V7.0
	Java Interface sample program

	概要：Separation Color

	Copyright 2021 Antenna House,Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class SeparationColor {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java SeparationColor in-pdf-file out-pdf-file");
            return;
        }

        try (PtlParamInput input = new PtlParamInput(args[0]);
             PtlParamOutput output = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            String separationName = "colorName";

            float c = 0.0f;             //シアンの値。0.0から1.0までの値
            float m = 1.0f;             //マゼンタの値。0.0から1.0までの値
            float y = 1.0f;             //黄の値。0.0から1.0までの値
            float k = 0.0f;             //黒の値。0.0から1.0までの値
            float sepValue = 0.5f;      //0.0 ～ 1.0までの値

            // PDFファイルをロードします。
            doc.load(input);

            try (PtlPages pages = doc.getPages();
                 PtlParamDrawShape shape = new PtlParamDrawShape();
                 PtlColorSpaceSeparation cs = new PtlColorSpaceSeparation(separationName, c, m, y, k);
                 PtlColorSeparation color = new PtlColorSeparation(cs, sepValue))
            {
                int pageCnt = doc.getPageCount();
                shape.setFillColor(color);
                shape.setLineColor(color);

                try (PtlPage page = pages.get(0);
                     PtlContent content = page.getContent();
                     PtlRect rect = new PtlRect(0.0f, 0.0f, 100.0f, 100.0f))  // Circle
                {
                    //円形を描画
                    content.drawCircle(rect, shape);
                }
                doc.save(output);
            }
        }
        catch (PtlException pex) {
            System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }
}
