/*
    Antenna House PDF Tool API V7.0
    Java Interface sample program

    概要：閲覧制限設定

    Copyright 2015-2021 Antenna House, Inc.
*/

package Sample;

import jp.co.antenna.ptl.*;

public class SetRestriction {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        if (args.length < 2)
        {
            System.out.println("usage: java SetRestriction in-pdf-file out-pdf-file");
            return;
        }

        try (PtlParamInput inputFile = new PtlParamInput(args[0]);
             PtlParamOutput outputFile = new PtlParamOutput(args[1]);
             PtlPDFDocument doc = new PtlPDFDocument())
        {
            // PDFファイルをロードします。
            doc.load(inputFile);

            // 閲覧制限設定
            setRestriction(doc);

            // ファイルに保存します。
            doc.save(outputFile);
        }
        catch (PtlException pex) {
             System.out.println("PtlException : ErrorCode = " + pex.getErrorCode() + "\n  " + pex.getErrorMessage());
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        catch (Error ex) {
            System.out.println(ex.getMessage());
            ex.printStackTrace();
        }
        finally {
            System.out.println("-- 完了 --");
        }
    }

    public static void setRestriction(PtlPDFDocument doc) throws PtlException, Exception, Error
    {
        try (PtlParamRestriction restruction = new PtlParamRestriction())
        {
            // 閲覧可能とするURLの追加
            restruction.appendValidURL("C:\\test\\");

            // 閲覧可能とする期間の開始日(2013/1/1 15:00:30)
            try (PtlDate dateStart = new PtlDate(2013, 1, 1, 15, 0, 30))
            {
                restruction.setValidTermStart(dateStart);
            }

            // 閲覧可能とする期間の終了日(2020/1/1 9:30:00)
            try (PtlDate dateEnd = new PtlDate(2020, 1, 1, 9, 30, 0))
            {
                restruction.setValidTermEnd(dateEnd);
            }

            // 透かしの設定
            setWaterMark(restruction);

            // 閲覧制限の設定
            doc.setRestriction(restruction);
        }
    }

    public static void setWaterMark(PtlParamRestriction restruction) throws PtlException, Exception, Error
    {
        try (PtlParamWaterMarkText watermarktext = new PtlParamWaterMarkText())
        {
            // 透かしの配置の設定 ALIGN_CENTER = 5 /* 中央 */
            watermarktext.setAlign(PtlParamWaterMark.ALIGN.ALIGN_CENTER);

            // 透かしに指定する文字列の設定
            watermarktext.setString("Restriction Test");

            // 透かしに指定するフォントの設定
            try (PtlParamFont font = new PtlParamFont("Helvetica", 180.0f, PtlParamFont.WEIGHT.WEIGHT_HEAVY, true, false))
            {
                watermarktext.setFont(font);
            }

            // 透かしの文字に指定する色の設定
            try (PtlColorDeviceRGB colorText = new PtlColorDeviceRGB(1.0f, 0.0f, 0.0f))
            {
                watermarktext.setTextColor(colorText);
            }

            // 透かしの文字の縁取りに指定する色の設定
            try (PtlColorDeviceRGB colorOutline = new PtlColorDeviceRGB(0.0f, 1.0f, 0.0f))
            {
                watermarktext.setOutlineColor(colorOutline);
            }

            // 透かしのテキストを対角線上に配置する設定
            watermarktext.setWriteDiagonal(true);

            // 閲覧不可時に表示するウォーターマーク設定
            restruction.setWatermark(watermarktext);
        }
    }
}
